package com.unis.crk.common.service;

import com.alibaba.fastjson.JSONObject;

public interface   IDataCenterDownloadService {
    /**
     * 接收ddm通知单
     * @param object
     * @param routerKey
     * @return
     */
    JSONObject savetTzd(String object, String routerKey);

    /**
     * 接收ddm车辆信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveClxx(String object, String routingKey);

    /**
     *接收ddm人员信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject savetRyxx(String object, String routingKey);


    /**
     * 接收ddm计量单位信息
     * @param object
     * @param routingKey
     */
    JSONObject savetjldw(String object, String routingKey);
    /**
     * 接收ddm计量单位信息
     * @param object
     * @param routingKey
     */
    JSONObject savetpz(String object, String routingKey);

    /**
     * 接收ddm品牌信息
     * @param object
     * @param routingKey
     */
    JSONObject savetpp(String object, String routingKey);

    /**
     * 接收市单位信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject savetsdwxx(String object, String routingKey);

    /**
     * 接收市单位信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject savetzdwxx(String object, String routingKey);


    /**
     * 接收ddm原粮通知单
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject savetYlTzd(String object, String routingKey);

    /**
     * 接受ddm商品信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject savesp(String object, String routingKey);

    /**
     * 接受ddm仓房信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveCf(String object, String routingKey);

    /**
     * 接受ddm货位信息
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveHw(String object, String routingKey);

    /**
     * 接收用户中心用户中心
     * @param jsonObject
     * @return
     */
    JSONObject downUserInfos(JSONObject jsonObject);

    /**
     * 生产加工
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveScjg(String object, String routingKey) throws Exception;

    /**
     * 移仓
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveYcr(String object, String routingKey) throws Exception;

    /**
     * 移仓
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveYcc(String object, String routingKey) throws Exception;
    /**
     * 供应商
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject  saveGys(String object, String routingKey) throws Exception;

    /**
     * 质检机构
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveZjjg(String object, String routingKey);

    /**
     * 质量标准
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject saveZlbz(String object, String routingKey);

    /**
     * 商家确认收到退货，保存售后订单
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject storeConfirm(String object, String routingKey);

    /**
     * 商家确认发货，报错订单数据
     * @param object
     * @param routingKey
     * @return
     */
    JSONObject delivery(String object, String routingKey);
}
